#!/bin/bash

# Variables for paths
PARSER=${PARSER:='parseAF'}
JEDI=${JEDI:='JediSat'}
IDEALASP=${IDEALASP:='ideal.dl'}
CLINGO=${CLINGO:='clingo'}
# instance
INST=${INST:=''}
WORKINGDIR=${WORKINGDIR:=''}
TMPDIR=${TMPDIR:=''}

usage() {
echo $0 "instance"
echo "instance AF in ASP format: (one per line)"
echo "           arg(x).   ... x is an argument"
echo "           att(x,y). ... x attacks y"
}

INST=$1

# usage
if [ "$INST" == "" ];then
usage
exit 1
fi

WORKINGDIR=`dirname $0`

# create a bunch of tmp fifos, since may solver cannot usually read from stdin all the time
TMPDIR=$(mktemp -d)
trap 'rm -rf "$TMPDIR"' EXIT INT TERM HUP

mkfifo "$TMPDIR/TMPDIMACS"
mkfifo "$TMPDIR/TMPMAP"
mkfifo "$TMPDIR/TMPERR"
mkfifo "$TMPDIR/TMPJEDI"

# parse instance to DIMACs, save mappings (e.g. arg(a) has variable 2 in DIMACS)
$WORKINGDIR/$PARSER $INST > $TMPDIR/TMPDIMACS 2> $TMPDIR/TMPERR &
grep "map" $TMPDIR/TMPERR > $TMPDIR/TMPMAP &

# apply backbone algorithm (JEDI)
$WORKINGDIR/$JEDI $TMPDIR/TMPDIMACS $TMPDIR/TMPJEDI > /dev/null 2> /dev/null &

# apply the restricted characteristic function (postprocessing)
cat $TMPDIR/TMPJEDI | head -n 4 | tail -n 1 | grep -o "\-[0-9]*" | grep -o "[0-9]*" | awk '{print "skeptReject("$1")."}' | $WORKINGDIR/$CLINGO - $TMPDIR/TMPMAP $WORKINGDIR/$IDEALASP $INST | grep  "ideal"

# cleanup handled by signal